@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 set -ex
-. venv/bin/activate
+. venv3/bin/activate
 fullrelease
-git push taichino && git push taichino --tags
+git push && git push --tags
 # vim:set et sts=4 ts=4 tw=80:
