@@ -3,8 +3,10 @@
 
 import unittest
 from datetime import datetime, timedelta
+
 import pytz
-from croniter import croniter, croniter_range, CroniterBadDateError, CroniterBadCronError, CroniterBadTypeRangeError
+
+from croniter import CroniterBadCronError, CroniterBadDateError, CroniterBadTypeRangeError, croniter, croniter_range
 from croniter.tests import base
 
 
@@ -13,16 +15,15 @@ class mydatetime(datetime):
 
 
 class CroniterRangeTest(base.TestCase):
-
     def test_1day_step(self):
         start = datetime(2016, 12, 2)
         stop = datetime(2016, 12, 10)
-        fwd = list(croniter_range(start, stop, '0 0 * * *'))
+        fwd = list(croniter_range(start, stop, "0 0 * * *"))
         self.assertEqual(len(fwd), 9)
         self.assertEqual(fwd[0], start)
         self.assertEqual(fwd[-1], stop)
         # Test the same, but in reverse
-        rev = list(croniter_range(stop, start, '0 0 * * *'))
+        rev = list(croniter_range(stop, start, "0 0 * * *"))
         self.assertEqual(len(rev), 9)
         # Ensure forward/reverse are a mirror image
         rev.reverse()
@@ -32,12 +33,12 @@ class CroniterRangeTest(base.TestCase):
         # Test without ends (exclusive)
         start = datetime(2016, 12, 2)
         stop = datetime(2016, 12, 10)
-        fwd = list(croniter_range(start, stop, '0 0 * * *', exclude_ends=True))
+        fwd = list(croniter_range(start, stop, "0 0 * * *", exclude_ends=True))
         self.assertEqual(len(fwd), 7)
         self.assertNotEqual(fwd[0], start)
         self.assertNotEqual(fwd[-1], stop)
         # Test the same, but in reverse
-        rev = list(croniter_range(stop, start, '0 0 * * *', exclude_ends=True))
+        rev = list(croniter_range(stop, start, "0 0 * * *", exclude_ends=True))
         self.assertEqual(len(rev), 7)
         self.assertNotEqual(fwd[0], stop)
         self.assertNotEqual(fwd[-1], start)
@@ -45,7 +46,7 @@ class CroniterRangeTest(base.TestCase):
     def test_1month_step(self):
         start = datetime(1982, 1, 1)
         stop = datetime(1983, 12, 31)
-        res = list(croniter_range(start, stop, '0 0 1 * *'))
+        res = list(croniter_range(start, stop, "0 0 1 * *"))
         self.assertEqual(len(res), 24)
         self.assertEqual(res[0], start)
         self.assertEqual(res[5].day, 1)
@@ -53,8 +54,8 @@ class CroniterRangeTest(base.TestCase):
 
     def test_1minute_step_float(self):
         start = datetime(2000, 1, 1, 0, 0)
-        stop =  datetime(2000, 1, 1, 0, 1)
-        res = list(croniter_range(start, stop, '* * * * *', ret_type=float))
+        stop = datetime(2000, 1, 1, 0, 1)
+        res = list(croniter_range(start, stop, "* * * * *", ret_type=float))
         self.assertEqual(len(res), 2)
         self.assertEqual(res[0], 946684800.0)
         self.assertEqual(res[-1] - res[0], 60)
@@ -80,29 +81,34 @@ class CroniterRangeTest(base.TestCase):
             list(croniter_range(f_start1, dt_stop1, "0 * * * *"))
 
     def test_timezone_dst(self):
-        """ Test across DST transition, which technically is a timzone change. """
+        """Test across DST transition, which technically is a timzone change."""
         tz = pytz.timezone("US/Eastern")
         start = tz.localize(datetime(2020, 10, 30))
-        stop =  tz.localize(datetime(2020, 11, 10))
-        res = list(croniter_range(start, stop, '0 0 * * *'))
+        stop = tz.localize(datetime(2020, 11, 10))
+        res = list(croniter_range(start, stop, "0 0 * * *"))
         self.assertNotEqual(res[0].tzinfo, res[-1].tzinfo)
         self.assertEqual(len(res), 12)
 
     def test_extra_hour_day_prio(self):
         def datetime_tz(*args, **kw):
-            """ Defined this in another branch.  single-use-version """
+            """Defined this in another branch.  single-use-version"""
             tzinfo = kw.pop("tzinfo")
             return tzinfo.localize(datetime(*args))
+
         tz = pytz.timezone("US/Eastern")
         cron = "0 3 * * *"
         start = datetime_tz(2020, 3, 7, tzinfo=tz)
         end = datetime_tz(2020, 3, 11, tzinfo=tz)
-        ret = [ i.isoformat() for i in croniter_range(start, end, cron) ]
-        self.assertEqual(ret, [
-            "2020-03-07T03:00:00-05:00",
-            "2020-03-08T03:00:00-04:00",
-            "2020-03-09T03:00:00-04:00",
-            "2020-03-10T03:00:00-04:00"])
+        ret = [i.isoformat() for i in croniter_range(start, end, cron)]
+        self.assertEqual(
+            ret,
+            [
+                "2020-03-07T03:00:00-05:00",
+                "2020-03-08T03:00:00-04:00",
+                "2020-03-09T03:00:00-04:00",
+                "2020-03-10T03:00:00-04:00",
+            ],
+        )
 
     def test_issue145_getnext(self):
         # Example of quarterly event cron schedule
@@ -131,7 +137,8 @@ class CroniterRangeTest(base.TestCase):
         # trivial example extending croniter
 
         class croniter_nosec(croniter):
-            """ Like croniter, but it forbids second-level cron expressions. """
+            """Like croniter, but it forbids second-level cron expressions."""
+
             @classmethod
             def expand(cls, expr_format, *args, **kwargs):
                 if len(expr_format.split()) == 6:
@@ -139,7 +146,15 @@ class CroniterRangeTest(base.TestCase):
                 return croniter.expand(expr_format, *args, **kwargs)
 
         cron = "0 13 8 1,4,7,10 wed"
-        matches = list(croniter_range(datetime(2020, 1, 1), datetime(2020, 12, 31), cron, day_or=False, _croniter=croniter_nosec))
+        matches = list(
+            croniter_range(
+                datetime(2020, 1, 1),
+                datetime(2020, 12, 31),
+                cron,
+                day_or=False,
+                _croniter=croniter_nosec,
+            )
+        )
         self.assertEqual(len(matches), 3)
 
         cron = "0 1 8 1,15,L wed 15,45"
@@ -149,25 +164,38 @@ class CroniterRangeTest(base.TestCase):
 
         with self.assertRaises(CroniterBadCronError):
             # Should similarly fail because the custom class rejects seconds expr
-            i = croniter_range(datetime(2020, 1, 1), datetime(2020, 12, 31), cron, _croniter=croniter_nosec)
+            i = croniter_range(
+                datetime(2020, 1, 1),
+                datetime(2020, 12, 31),
+                cron,
+                _croniter=croniter_nosec,
+            )
             next(i)
 
     def test_dt_types(self):
         start = mydatetime(2020, 9, 24)
         stop = datetime(2020, 9, 28)
         try:
-            list(croniter_range(start, stop, '0 0 * * *'))
+            list(croniter_range(start, stop, "0 0 * * *"))
         except CroniterBadTypeRangeError:
-            self.fail('should not be triggered')
+            self.fail("should not be triggered")
 
     def test_configure_second_location(self):
         start = datetime(2016, 12, 2, 0, 0, 0)
         stop = datetime(2016, 12, 2, 0, 1, 0)
-        fwd = list(croniter_range(start, stop, '*/20 * * * * *', second_at_beginning=True))
+        fwd = list(croniter_range(start, stop, "*/20 * * * * *", second_at_beginning=True))
         self.assertEqual(len(fwd), 4)
         self.assertEqual(fwd[0], start)
         self.assertEqual(fwd[-1], stop)
 
+    def test_year_range(self):
+        start = datetime(2010, 1, 1)
+        stop = datetime(2030, 1, 1)
+        fwd = list(croniter_range(start, stop, "0 0 1 1 ? 0 2020-2024,2028"))
+        self.assertEqual(len(fwd), 6)
+        self.assertEqual(fwd[0], datetime(2020, 1, 1))
+        self.assertEqual(fwd[-1], datetime(2028, 1, 1))
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     unittest.main()
